@@ -57,6 +57,8 @@ namespace lib {
             String               m_profileDirectory;               /// @brief The profile DIR to use for the application
             String               m_pluginDirectory;                /// @brief //TODO Plugins? Get set in ARCH but doesn't seem to get used
             String               m_tlsCertFile;                    /// @brief Contains the location of the TLS certificate file
+            bool                 m_enableLangSync = true;          /// @brief Should keyboard input be in same language as on server
+            bool                 m_preventSleep = false;           /// @brief Stop this computer from sleeping
 
 #if SYSAPI_WIN32
             bool                 m_debugServiceWait  = false;
@@ -76,4 +78,4 @@ namespace lib {
     }
 }
 
-#endif //SYNERGY_CORE_ARGSBASE_H
\ No newline at end of file
+#endif //SYNERGY_CORE_ARGSBASE_H
